"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.loadAliasConfigs = void 0;
var find_up_1 = require("find-up");
var micromatch_1 = __importDefault(require("micromatch"));
var path_1 = require("path");
var tsconfig_paths_1 = require("tsconfig-paths");
function loadAliasConfigs(cwd, aliasConfigPath) {
    var configFilePath = (0, find_up_1.sync)([aliasConfigPath, "tsconfig.json", "jsconfig.json"].filter(Boolean), { cwd: cwd });
    if (!configFilePath) {
        return new Error("cannot find TSConfig or JSConfig, try assigning aliasConfigPath");
    }
    var config;
    try {
        config = (0, tsconfig_paths_1.loadConfig)(configFilePath);
    }
    catch (error) {
        if (error instanceof SyntaxError) {
            return new Error("SyntaxError in TSConfig/JSConfig: ".concat(error.message));
        }
        throw error;
    }
    if (config.resultType !== "success") {
        return new Error("validate tsconfig or jsconfig provided and ensure compilerOptions.baseUrl is set: ".concat(config.message));
    }
    var configDir = (0, path_1.dirname)(configFilePath);
    var projectBaseDir = (0, path_1.join)(configDir, config.baseUrl);
    return Object.entries(config.paths).reduce(function (configs, _a) {
        var aliasGlob = _a[0], aliasPaths = _a[1];
        aliasPaths.forEach(function (aliasPath) {
            var relativePathBase = micromatch_1["default"].scan(aliasPath).base;
            configs.push({
                alias: micromatch_1["default"].scan(aliasGlob).base,
                path: {
                    absolute: (0, path_1.join)(projectBaseDir, relativePathBase)
                }
            });
        });
        return configs;
    }, []);
}
exports.loadAliasConfigs = loadAliasConfigs;
